Learn R Programming

geophys (version 1.2-1)

tauline: Shear Stress along Line

Description

Calculate the shear stress along an arbitrary line in a plane with stress orientation

Usage

tauline(Rp, P1, P2, Rview, ES, NN)
tauplane(Rp, L, Rview, ES, NN)

Arguments

Rp
rotated points describing plane
P1
point 1 extracted from screen (locator)
P2
point 2 extracted from screen
Rview
rotation matrix for viewing
ES
eigen value decomposition from eigen
NN
normal vector to plan in unrotated coordinates
L
list locations (x,y) in the figure, projected to the plane

Value

  • shear stress along the line indicated

Details

Used internally in stress. When the plan is plotted, if two points are located on the figure, the points are positions on the plan and un-rotated using the Rview matrix. Then the shear stress in the plan along that line is calculated and returned.

See Also

stress,NORMvec

Examples

Run this code
S= stressSETUP()


pstart()

     PLOTplane(S$Rp, planecol="brown")
     PLOTbox(S$Rax, S$Rbox, axcol= 'green', boxcol= 'purple')




##  L = locator(2)

L=list()
L$x=c(-13.6305297057, 52.6412739525)
L$y=c(26.2697350325,32.4501696158)


Stensor = matrix(c(
15, 0, 0,
0, 10, 0,
0,  0, 5), ncol=3)


P1 = list(x=L$x[1], y=L$y[1])
P2 = list(x=L$x[2], y=L$y[2])


ES = eigen(Stensor) 
NN = NORMvec(S$PPs, S$xscale, S$Rview, aglyph=S$aglyph, add=FALSE)

tauline(S$Rp, P1, P2, S$Rview, ES, NN)

Run the code above in your browser using DataLab