Learn R Programming

geophys (version 1.2-1)

randpoles: Random Poles

Description

Create a set of random poles distributed around a given pole.

Usage

randpoles(az, iang, alphadeg, opt = "unif", BALL.radius = 1, N = 10, add = TRUE, ...)

Arguments

az
azimuth of given direction
iang
inclination angle of given direction
alphadeg
standard error for distribution
opt
Optional distribution, "unif" or "norm"
BALL.radius
radius of small circle to draw
N
Number of points to create
add
logical, TRUE=add points to net plot
...
graphical parameters for plotting

Value

  • azazimuths of new poles
  • dipdips of new poles
  • xx position on plot
  • yy position on plot

Details

A given geographic pole is supplied and N normally or uniformly distributed poles are created.

See Also

net

Examples

Run this code
net();
GG = randpoles(30, 40, 10, opt="norm", N=20)

addsmallcirc(30, 40, 10)

Run the code above in your browser using DataLab